/******************************************************************************
 * Copyright 2023 TypeFox GmbH
 * This program and the accompanying materials are made available under the
 * terms of the MIT License, which is available in the project root.
 ******************************************************************************/
import { Check, Container, Module } from './types';
/**
 * Creates a container from the given modules.
 * The modules are merged and the dependencies are injected.
 * The container is a proxy that lazily creates the dependencies.
 * The dependencies are cached and reused.
 *
 * @param modules The modules to be merged and injected.
 * @returns The container.
 */
export declare function inject<Modules extends Module[]>(...modules: Check<Modules>): Container<Modules>;
/**
 * Marks a group or factory to be eagerly evaluated.
 * Eager groups and factories are evaluated when the container is created.
 *
 * @param val The group or factory to be eagerly evaluated.
 * @returns A new instance of the group or factory.
 */
export declare function init<T extends object | Function>(val: T): T;
//# sourceMappingURL=inject.d.ts.map